import {
  Controller,
  Post,
  Body,
  Headers,
  HttpCode,
  HttpStatus,
  BadRequestException,
} from '@nestjs/common';
import { SharedService } from './shared.service';
import { ApiTags, ApiOperation, ApiResponse, ApiHeader } from '@nestjs/swagger';
import { SHARED_TYPES } from './shared.module';

@ApiTags('spaces')
@Controller('spaces')
export class SpacesController {
  constructor(private readonly sharedService: SharedService) { }

  @ApiOperation({ summary: 'Shared a Space' })
  @ApiResponse({ status: 201, description: 'Space successfully shared.' })
  @ApiHeader({
    name: 'x-zen-shared-name',
    description: 'Name of the Space',
    required: true,
  })
  @ApiHeader({
    name: 'x-zen-shared-author',
    description: 'Author of the Space',
    required: true,
  })
  @ApiHeader({
    name: 'User-Agent',
    description: 'User-Agent',
    required: true,
  })
  @Post()
  async createSpace(
    @Body() content: string,
    @Headers() headers: Record<string, string>,
    @Headers('x-zen-shared-token') token: string,
  ) {
    const contentString =
      typeof content === 'string' ? content : JSON.stringify(content);

    this.validateFileSize(contentString); // Validate file size

    return this.sharedService.create(SHARED_TYPES.WORKSPACE, contentString, token, headers);
  }

  private validateFileSize(content: string) {
    const sizeInBytes = Buffer.byteLength(content, 'utf-8');
    const maxSizeInBytes = 1 * 1024 * 512; // 1 MB
    if (sizeInBytes > maxSizeInBytes) {
      throw new BadRequestException(
        `The uploaded content exceeds the size limit of 512 KB.`,
      );
    }
  }
}
